##  Step 1. Upload Application Data into SAP LeanIX
Identify Application Owners: One of the initial steps in uploading Application Data is to identify the owners and users of the applications you are assessing. This is necessary to gather all the relevant information needed.
Gather data: Gather as much relevant information about the applications in your organization, covering their technical and business attributes, ownership, and costs. The most relevant ones for a portfolio assessment are Technical Fit, Functional Fit, and Business Criticality. If you are assessing for Cloud Migration, you can think of Cloud Readiness, hosting type, or any customized attributes that you might use within your organization.
The efficient way to get the data into your workspace is with Excel Import/Export capabilities in the Inventory. To learn more, see [Importing Fact Sheet Data Through Excel File](https://help.sap.com/docs/leanix/ea/importing-fact-sheet-data-through-excel-file?locale=en-US&state=PRODUCTION&version=CLOUD "SAP LeanIX’s import feature enables efficient bulk updates, including adding, updating, and archiving fact sheets. This guide provides formatting rules, error handling, and step-by-step guidance for importing data through an Excel file.").
**Note**
When creating new application fact sheets, choose a meaningful display name, something a common user can understand at first glance.
Check/validate all attributes: After you have uploaded the initial data, say 50-300 applications, it is time to shape up your data by validating. You can do simple infield editing in the Fact Sheets, but the more efficient approach is to do bulk editing by going to the Inventory.
To do bulk editing, follow these steps:
  1. Navigate to Inventory and select Application fact sheet from the filter panel on the left.
  2. Choose Table view from the upper right corner.
  3. Click on the Eye icon and add relevant columns to the Active columns list to make it visible.
  4. Click Edit, and edit any information inline as you would using Excel.
  5. Click Save to finish.


To learn more about modeling the Application Fact Sheet, see the [Application Modeling Guidelines](https://help.sap.com/docs/leanix/ea/application-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD "This page guides you on modeling applications, covering subtypes, best practices, versioning, hierarchies, and use cases. Avoid common antipatterns and gain valuable insights.").
